pub struct CleanupGuard<F: FnOnce()> { /* private fields */ }Expand description
Guard that ensures cleanup runs at the end of a test.
This is useful for tests that need to clean up resources even if the test panics.
Implementations