pub struct ResponseAssertion<T> { /* private fields */ }Expand description
Response assertion builder for server functions that return HTTP-like responses.
Implementations
Sourceimpl<T> ResponseAssertion<T>
impl<T> ResponseAssertion<T>
Sourcepub fn with_status(self, status: StatusCode) -> Self
pub fn with_status(self, status: StatusCode) -> Self
Set the expected status code.
Sourcepub fn into_value(self) -> T
pub fn into_value(self) -> T
Consume and return the value.
Sourceimpl<T: HasStatusCode> ResponseAssertion<T>
impl<T: HasStatusCode> ResponseAssertion<T>
Sourcepub fn should_have_status(&self, expected: StatusCode)
pub fn should_have_status(&self, expected: StatusCode)
Assert that the status code matches.
Sourcepub fn should_be_success(&self)
pub fn should_be_success(&self)
Assert that the response is successful (2xx).
Sourcepub fn should_be_client_error(&self)
pub fn should_be_client_error(&self)
Assert that the response is a client error (4xx).
Sourcepub fn should_be_server_error(&self)
pub fn should_be_server_error(&self)
Assert that the response is a server error (5xx).