pub struct TestSavepoint {
pub name: String,
/* private fields */
}Expand description
Wrapper for managing savepoints within a test.
Savepoints allow you to create checkpoints within a transaction and rollback to them without rolling back the entire transaction.
Fields
name: StringThe savepoint name.
Implementations
Sourceimpl TestSavepoint
impl TestSavepoint
Sourcepub fn mark_released(&mut self)
pub fn mark_released(&mut self)
Mark the savepoint as released.
Sourcepub fn is_released(&self) -> bool
pub fn is_released(&self) -> bool
Check if the savepoint has been released.