Module views

Module views 

Test view implementations for integration testing. View test utilities for Reinhardt framework

Provides test models, request builders, and test views for view testing.

Structs

ApiTestModel
Test model for API view tests
ApiTestModelFields
Field selector for the associated test model.
ErrorTestView
Create a view that always returns an error for testing error handling
SimpleTestView
Create a simple view for testing basic functionality
TestModel
Test model for view tests
TestModelFields
Field selector for the associated test model.

Enums

ErrorKind
Kind of error that an ErrorTestView will produce.

Functions

create_api_test_objects
Create test objects for API views
create_json_request
Create a test request with JSON body
create_large_test_objects
Create a large set of test objects for pagination testing
create_request
Create a test request with the given parameters
create_request_with_headers
Create a test request with headers
create_request_with_path_params
Create a test request with path parameters
create_test_objects
Create test objects for list views