pub struct MockHttpResponse {
pub status: StatusCode,
pub headers: HeaderMap,
pub body: Bytes,
}Expand description
Mock HTTP response for testing.
This represents a response that can be returned from a server function or used for assertions.
Fields
status: StatusCodeHTTP status code.
headers: HeaderMapResponse headers.
body: BytesResponse body.
Implementations
Sourceimpl MockHttpResponse
impl MockHttpResponse
Sourcepub fn new(status: StatusCode) -> Self
pub fn new(status: StatusCode) -> Self
Create a new mock response with the given status.
Sourcepub fn no_content() -> Self
pub fn no_content() -> Self
Create a no content (204 No Content) response.
Sourcepub fn bad_request() -> Self
pub fn bad_request() -> Self
Create a bad request (400) response.
Create an unauthorized (401) response.
Sourcepub fn internal_error() -> Self
pub fn internal_error() -> Self
Create an internal server error (500) response.
Sourcepub fn with_status(self, status: StatusCode) -> Self
pub fn with_status(self, status: StatusCode) -> Self
Set the status code.
Sourcepub fn with_header(self, name: &str, value: &str) -> Self
pub fn with_header(self, name: &str, value: &str) -> Self
Add a header.
Add a Set-Cookie header.
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Check if the response is successful (2xx).
Sourcepub fn is_client_error(&self) -> bool
pub fn is_client_error(&self) -> bool
Check if the response is a client error (4xx).
Sourcepub fn is_server_error(&self) -> bool
pub fn is_server_error(&self) -> bool
Check if the response is a server error (5xx).
Sourcepub fn get_header(&self, name: &str) -> Option<&str>
pub fn get_header(&self, name: &str) -> Option<&str>
Get a header value.
Sourcepub fn json_body<T: for<'de> Deserialize<'de>>(&self) -> Result<T, Error>
pub fn json_body<T: for<'de> Deserialize<'de>>(&self) -> Result<T, Error>
Parse the body as JSON.
Sourcepub fn text_body(&self) -> Result<String, FromUtf8Error>
pub fn text_body(&self) -> Result<String, FromUtf8Error>
Get the body as a string.