Test view implementations for integration testing. View test utilities for Reinhardt framework
Provides test models, request builders, and test views for view testing.
Structs
- ApiTest
Model - Test model for API view tests
- ApiTest
Model Fields - Field selector for the associated test model.
- Error
Test View - Create a view that always returns an error for testing error handling
- Simple
Test View - Create a simple view for testing basic functionality
- Test
Model - Test model for view tests
- Test
Model Fields - Field selector for the associated test model.
Enums
- Error
Kind - Kind of error that an
ErrorTestViewwill produce.
Functions
- create_
api_ test_ objects - Create test objects for API views
- create_
json_ request - Create a test request with JSON body
- create_
large_ test_ objects - Create a large set of test objects for pagination testing
- create_
request - Create a test request with the given parameters
- create_
request_ with_ headers - Create a test request with headers
- create_
request_ with_ path_ params - Create a test request with path parameters
- create_
test_ objects - Create test objects for list views